@@ -282,6 +282,11 @@ static void ctk_event_class_init(CtkEventClass *ctk_event_class)
     MAKE_SIGNAL(NV_CTRL_GVI_DETECTED_CHANNEL_SMPTE352_IDENTIFIER);
     MAKE_SIGNAL(NV_CTRL_GVI_GLOBAL_IDENTIFIER);
     MAKE_SIGNAL(NV_CTRL_FRAMELOCK_SYNC_DELAY_RESOLUTION);
+    MAKE_SIGNAL(NV_CTRL_GPU_COOLER_MANUAL_CONTROL);
+    MAKE_SIGNAL(NV_CTRL_THERMAL_COOLER_LEVEL);
+    MAKE_SIGNAL(NV_CTRL_THERMAL_COOLER_LEVEL_SET_DEFAULT);
+    MAKE_SIGNAL(NV_CTRL_THERMAL_COOLER_CONTROL_TYPE);
+    MAKE_SIGNAL(NV_CTRL_THERMAL_COOLER_TARGET);
     MAKE_SIGNAL(NV_CTRL_GPU_POWER_MIZER_MODE);
     MAKE_SIGNAL(NV_CTRL_GVI_SYNC_OUTPUT_FORMAT);
     MAKE_SIGNAL(NV_CTRL_GVI_MAX_CHANNELS_PER_JACK);
@@ -364,6 +369,7 @@ static void ctk_event_class_init(CtkEventClass *ctk_event_class)
     MAKE_BINARY_SIGNAL(NV_CTRL_BINARY_DATA_FRAMELOCKS_USED_BY_GPU);
     MAKE_BINARY_SIGNAL(NV_CTRL_BINARY_DATA_GPUS_USING_VCSC);
     MAKE_BINARY_SIGNAL(NV_CTRL_BINARY_DATA_VCSCS_USED_BY_GPU);
+    MAKE_BINARY_SIGNAL(NV_CTRL_BINARY_DATA_COOLERS_USED_BY_GPU);
     MAKE_BINARY_SIGNAL(NV_CTRL_BINARY_DATA_GPUS_USED_BY_LOGICAL_XSCREEN);
 
 #undef MAKE_BINARY_SIGNAL
